intelmq.bots.parsers.blueliv package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.parsers.blueliv package

## Submodules

## intelmq.bots.parsers.blueliv.parser_crimeserver module

intelmq.bots.parsers.blueliv.parser_crimeserver.BOT

  alias of `intelmq.bots.parsers.blueliv.parser_crimeserver.BluelivCrimeserverParserBot`

class intelmq.bots.parsers.blueliv.parser_crimeserver.BluelivCrimeserverParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse data from the Blueliv Crimeserver API

  process()

## Module contents